/** @type {Refractor} */
export const refractor: Refractor
/**
 * A hidden Prism token
 */
export type _Token = {
  type: string
  content: string
  alias: string
  length: number
}
/**
 * A hidden Prism environment
 */
export type _Env = {
  type: string
  tag: string
  content: Text | RefractorElement | Array<Text | RefractorElement>
  classes: Array<string>
  attributes: {
    [x: string]: string
  }
  language: string
}
export type Root = import('hast').Root
export type Element = import('hast').Element
export type Text = import('hast').Text
export type RefractorElement = Omit<Element, 'children'> & {
  children: Array<RefractorElement | Text>
}
export type RefractorRoot = Omit<Root, 'children'> & {
  children: Array<RefractorElement | Text>
}
export type Languages = import('prismjs').Languages
/**
 * Whatever this is, Prism handles it.
 */
export type Grammar = import('prismjs').Grammar
/**
 * A refractor syntax function
 */
export type Syntax = ((prism: unknown) => void) & {
  displayName: string
  aliases?: string[]
}
/**
 * Virtual syntax highlighting
 */
export type Refractor = {
  highlight: typeof highlight
  alias: typeof alias
  register: typeof register
  registered: typeof registered
  listLanguages: typeof listLanguages
  languages: Languages
}
declare function Refractor(): void
/**
 * Parse `value` according to the `language` (name or alias)
 * syntax.
 *
 * @param {string} value
 * @param {string|Grammar} nameOrGrammar
 * @returns {RefractorRoot}
 */
declare function highlight(
  value: string,
  nameOrGrammar: string | Grammar
): RefractorRoot
/**
 * Register a new `alias` for the `name` language.
 *
 * @param {Object.<string, string|Array.<string>>|string} name
 * @param {string|Array.<string>} [alias]
 * @returns {void}
 */
declare function alias(
  name:
    | {
        [x: string]: string | Array<string>
      }
    | string,
  alias?: string | Array<string>
): void
/**
 * Register a syntax.
 * Needed if you’re using `refractor/core.js`.
 *
 * @param {Syntax} syntax
 * @returns {void}
 */
declare function register(syntax: Syntax): void
/**
 * Check if a `language` (name or alias) is registered.
 *
 * @param {string} language
 * @returns {boolean}
 */
declare function registered(language: string): boolean
/**
 * List all registered languages (names and aliases).
 *
 * @returns {Array.<string>}
 */
declare function listLanguages(): Array<string>
export {}
